package com.ruoyi.project.business.service;

import java.util.List;
import com.ruoyi.project.business.domain.TpParabarRelatedModel;

/**
 * 参数包关联梯型Service接口
 * 
 * @author ruoyi
 * @date 2024-04-28
 */
public interface ITpParabarRelatedModelService 
{
    /**
     * 查询参数包关联梯型
     * 
     * @param id 参数包关联梯型主键
     * @return 参数包关联梯型
     */
    public TpParabarRelatedModel selectTpParabarRelatedModelById(Long id);

    /**
     * 查询参数包关联梯型列表
     * 
     * @param tpParabarRelatedModel 参数包关联梯型
     * @return 参数包关联梯型集合
     */
    public List<TpParabarRelatedModel> selectTpParabarRelatedModelList(TpParabarRelatedModel tpParabarRelatedModel);

    /**
     * 新增参数包关联梯型
     * 
     * @param tpParabarRelatedModel 参数包关联梯型
     * @return 结果
     */
    public int insertTpParabarRelatedModel(TpParabarRelatedModel tpParabarRelatedModel);

    /**
     * 修改参数包关联梯型
     * 
     * @param tpParabarRelatedModel 参数包关联梯型
     * @return 结果
     */
    public int updateTpParabarRelatedModel(TpParabarRelatedModel tpParabarRelatedModel);

    /**
     * 批量删除参数包关联梯型
     * 
     * @param ids 需要删除的参数包关联梯型主键集合
     * @return 结果
     */
    public int deleteTpParabarRelatedModelByIds(Long[] ids);

    /**
     * 删除参数包关联梯型信息
     * 
     * @param id 参数包关联梯型主键
     * @return 结果
     */
    public int deleteTpParabarRelatedModelById(Long id);
}
