package com.ruoyi.project.business.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.business.domain.TpParabarRelatedModel;
import com.ruoyi.project.business.service.ITpParabarRelatedModelService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 参数包关联梯型Controller
 * 
 * @author ruoyi
 * @date 2024-04-28
 */
@RestController
@RequestMapping("/business/model")
public class TpParabarRelatedModelController extends BaseController
{
    @Resource
    private ITpParabarRelatedModelService tpParabarRelatedModelService;

    /**
     * 查询参数包关联梯型列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TpParabarRelatedModel tpParabarRelatedModel)
    {
        startPage();
        List<TpParabarRelatedModel> list = tpParabarRelatedModelService.selectTpParabarRelatedModelList(tpParabarRelatedModel);
        return getDataTable(list);
    }

    /**
     * 导出参数包关联梯型列表
     */
    @Log(title = "参数包关联梯型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TpParabarRelatedModel tpParabarRelatedModel)
    {
        List<TpParabarRelatedModel> list = tpParabarRelatedModelService.selectTpParabarRelatedModelList(tpParabarRelatedModel);
        ExcelUtil<TpParabarRelatedModel> util = new ExcelUtil<TpParabarRelatedModel>(TpParabarRelatedModel.class);
        util.exportExcel(response, list, "参数包关联梯型数据");
    }

    /**
     * 获取参数包关联梯型详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tpParabarRelatedModelService.selectTpParabarRelatedModelById(id));
    }

    /**
     * 新增参数包关联梯型
     */
    @Log(title = "参数包关联梯型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TpParabarRelatedModel tpParabarRelatedModel)
    {
        return toAjax(tpParabarRelatedModelService.insertTpParabarRelatedModel(tpParabarRelatedModel));
    }

    /**
     * 修改参数包关联梯型
     */
    @Log(title = "参数包关联梯型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TpParabarRelatedModel tpParabarRelatedModel)
    {
        return toAjax(tpParabarRelatedModelService.updateTpParabarRelatedModel(tpParabarRelatedModel));
    }

    /**
     * 删除参数包关联梯型
     */
    @Log(title = "参数包关联梯型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tpParabarRelatedModelService.deleteTpParabarRelatedModelByIds(ids));
    }
}
